@@ -232,7 +232,7 @@ bool ClientApp::kde_open(const QUrl& url, const QString& mimeType, bool allowExe
             mimeType, QLatin1String( "Application" ) );
         if (offers.isEmpty()) return 1;
         KService::Ptr serv = offers.first();
-        return KRun::run( *serv, urls, 0 );
+        return KRun::runService( *serv, urls, 0 );
     }
 }
 #endif
@@ -249,9 +249,8 @@ bool ClientApp::doCopy( const QStringList& urls )
     return m_ok;
 }
 
-void ClientApp::slotEntries(KIO::Job* job, const KIO::UDSEntryList& list)
+void ClientApp::slotEntries(KIO::Job*, const KIO::UDSEntryList& list)
 {
-    QUrl url = static_cast<KIO::ListJob*>( job )->url();
     KIO::UDSEntryList::ConstIterator it=list.begin();
     for (; it != list.end(); ++it) {
         // For each file...
@@ -262,7 +261,7 @@ void ClientApp::slotEntries(KIO::Job* job, const KIO::UDSEntryList& list)
 
 bool ClientApp::doList( const QStringList& urls )
 {
-    QUrl dir = urls.first();
+    QUrl dir = makeURL(urls.first());
     KIO::Job * job = KIO::listDir(dir, KIO::HideProgressInfo);
     if ( !s_interactive )
         job->setUiDelegate(0);
@@ -325,7 +324,8 @@ bool ClientApp::doIt(const QCommandLineParser& parser)
     if ( command == "openProperties" )
     {
         checkArgumentCount(argc, 2, 2); // openProperties <url>
-        KPropertiesDialog * p = new KPropertiesDialog(parser.positionalArguments().last(), 0 /*no parent*/ );
+        QUrl url = makeURL(parser.positionalArguments().last());
+        KPropertiesDialog * p = new KPropertiesDialog(url, 0 /*no parent*/ );
         QObject::connect( p, SIGNAL( destroyed() ), qApp, SLOT( quit() ));
         QObject::connect( p, SIGNAL( canceled() ), this, SLOT( slotDialogCanceled() ));
         p->show();
@@ -337,7 +337,8 @@ bool ClientApp::doIt(const QCommandLineParser& parser)
         if ( command == "cat" )
     {
         checkArgumentCount(argc, 2, 2); // cat <url>
-        KIO::TransferJob* job = KIO::get(parser.positionalArguments().last(), KIO::NoReload, s_jobFlags);
+        QUrl url = makeURL(parser.positionalArguments().last());
+        KIO::TransferJob* job = KIO::get(url, KIO::NoReload, s_jobFlags);
         if ( !s_interactive )
             job->setUiDelegate( 0 );
         connect(job, SIGNAL(data(KIO::Job*,QByteArray) ), this, SLOT(slotPrintData(KIO::Job*,QByteArray)));
